@@ -1,10 +1,11 @@
 from .run import run_ebm
 from .utils.generate_data import generate
-from .data import get_sample_data_path, get_params_path
+from .data import get_sample_data_path, get_params_path, get_biomarker_order_path
 
 __all__ = [
     "run_ebm",
     "generate",
     "get_sample_data_path",
-    "get_params_path"
+    "get_params_path",
+    "get_biomarker_order_path"
 ]
\ No newline at end of file
